import { DeepClientInstance, SerialOperation } from '@deep-foundation/deeplinks/imports/client.js';
import { MotionInfo } from './motion-info.js';
import { MotionDecorator } from './create-motion-decorator.js';
/**
  * Gets serial operations to insert Motion
  *
  * @example
 ```ts
 const serialOperations = await makeMotionInsertOperations({
   deep
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export declare function makeMotionInsertOperations<TDeepClient extends DeepClientInstance>(this: MotionDecorator<TDeepClient>, options: MakeMotionInsertOperationsOptions): Promise<{
    operations: (SerialOperation<"insert", "links"> | SerialOperation<"insert", "objects">)[];
    motionLinkId: number;
    containLinkId: number;
}>;
export interface MakeMotionInsertOperationsOptions {
    /**
     * Reserved link ids that will be used in the serial operations
     */
    reservedLinkIds?: {
        /**
         * Reserved link id for the motion
         */
        motionLinkId?: number;
        /**
         * Reserved link id for the contain
         */
        containLinkId?: number;
    };
    /**
     * Link ids of types that will be used in the serial operations
     */
    typeLinkIds?: {
        /**
         * Link id of the contain type
         */
        containTypeLinkId?: number;
        /**
         * Link id of the motion type
         */
        motionTypeLinkId?: number;
    };
    /**
     * Motion Info
     */
    info: MotionInfo;
    /**
     * Link id of the container
     *
     * @remarks
     * If it is null, contain link will not be created
     * @defaultValue {@link MakeMotionInsertOperationsOptions.deep.linkId} if not provided or undefined
     */
    containerLinkId?: number | undefined | null;
    /**
     * Value of the contain link
     *
     * @remarks
     * If {@link MakeMotionInsertOperationsOptions.containerLinkId} is null, this will be ignored
     */
    containValue?: string | undefined;
}
