import { createSerialOperation } from '@deep-foundation/deeplinks/imports/gql/index.js';
import { packageLog } from './package-log.js';
/**
  * Gets serial operations to insert Motion
  *
  * @example
 ```ts
 const serialOperations = await makeMotionInsertOperations({
   deep
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export async function makeMotionInsertOperations(options) {
    const log = packageLog.extend(makeMotionInsertOperations.name);
    log({ Options: options });
    const { info, containerLinkId, } = options;
    log({ info });
    const { containValue } = options;
    const reservedLinkIds = await this.reserve(2);
    log({ reservedLinkIds });
    const motionLinkId = options.reservedLinkIds?.motionLinkId ?? reservedLinkIds.pop();
    log({ motionLinkId });
    const containLinkId = options.reservedLinkIds?.containLinkId ?? reservedLinkIds.pop();
    log({ containLinkId });
    const operations = [
        createSerialOperation({
            type: 'insert',
            table: 'links',
            objects: {
                id: motionLinkId,
                type_id: this.capacitorMotionPackage.Motion.idLocal(),
            },
        }),
        createSerialOperation({
            type: 'insert',
            table: 'objects',
            objects: {
                link_id: motionLinkId,
                value: info,
            }
        }),
        createSerialOperation({
            type: 'insert',
            table: 'links',
            objects: {
                id: containLinkId,
                type_id: this.idLocal("@deep-foundation/core", "Contain"),
                from_id: containerLinkId || this.linkId,
                to_id: motionLinkId,
                ...(containValue ? { value: containValue } : {})
            }
        })
    ];
    log({ operations });
    return {
        operations,
        motionLinkId,
        containLinkId,
    };
}
