import { MotionInfo } from '../motion-info.js';
import { MotionDecorator } from '../create-motion-decorator.js';
/**
 * Returns a subscription handler for the acceleration/orientation event
 *
 * @remarks It is not recommended to use this function directly. Instead use {@link WithAccelerationSync} or {@link WithOrientationSync}
 *
 * @example
 * #### Handle acceleration event
```ts
const accelerationHandlerFunction = getSubscriptionHandler({
    containerLinkId,
});
const accelerationHandler = Motion.addListener(
  'accel',
  accelerationHandlerFunction
);
return () => {
  accelerationHandler.remove();
};
```
  * #### Handle orientation event
```ts
useEffect(() => {
  const accelerationHandlerFunction = getSubscriptionHandler({
            containerLinkId,
  })
  const orientationHandler = Motion.addListener('orientation', (event) => {
      accelerationHandlerFunction({
        rotationRate: event
      })
  });
  return () => {
      orientationHandler.remove();
  }
}, [deep, containerLinkId])
```
 */
export declare function getSubscriptionHandler(this: MotionDecorator, options: GetSubscriptionHandlerOptions): (paramInfo: MotionInfo) => Promise<void>;
export interface GetSubscriptionHandlerOptions {
    /**
     * A container link id
     */
    containerLinkId: number;
}
