import { Motion } from '@capacitor/motion';
import { useEffect } from 'react';
import createDebugMessages from 'debug';
import { Package } from '../../package.js';
/**
 * This hook subscribes to the acceleration event and saves the data to Deep
 *
 * @remarks
 * It is not recommended to use this hook directly. Instead of {@link WithAccelerationSync}
 *
 * @example
```ts
useAccelerationSync({
    containerLinkId
})
```
 */
export function useAccelerationSync(options) {
    const { deep, containerLinkId = deep.linkId } = options;
    const $package = new Package({ deep: deep });
    const debug = createDebugMessages(`${$package.name}:useAccelerationSync`);
    debug({ options });
    useEffect(() => {
        const accelerationHandlerFunction = deep.getSubscriptionHandler({
            containerLinkId,
        });
        const accelerationHandler = Motion.addListener('accel', accelerationHandlerFunction);
        debug({ accelerationHandler });
        return () => {
            accelerationHandler.remove();
        };
    }, [deep, containerLinkId]);
}
