import { Motion } from "@capacitor/motion";
import { useEffect } from "react";
import createDebugMessages from 'debug';
/**
 * This hook subscribes to the orientation event and saves the data to Deep
 *
 * @remarks
 * It is not recommended to use this hook directly. Instead of {@link WithOrientationSync}
 *
 * @exaple
```ts
useOrientationSync({
      containerLinkId
})
```
 */
export function useOrientationSync(options) {
    const { deep, containerLinkId = deep.linkId } = options;
    const debug = createDebugMessages(`${deep.capacitorMotionPackage.name}:useOrientationSync`);
    debug({ options });
    useEffect(() => {
        const accelerationHandlerFunction = deep.getSubscriptionHandler({
            containerLinkId,
        });
        const orientationHandler = Motion.addListener('orientation', (event) => {
            accelerationHandlerFunction({
                rotationRate: event
            });
        });
        return () => {
            orientationHandler.remove();
        };
    }, [deep, containerLinkId]);
}
