import { Motion } from '@capacitor/motion';
/**
 * Subscribes to acceleration changes and saves them
 *
 * @remarks
 * Motion permissions should be granted before calling this function by using {@link requestMotionPermissions}
 * Acceleration data is saved by using {@link makeMotionValueUpdateOperations} with {@link GetMotionInsertSerialOperationsOptions.containerLinkId} set to {@link SubscribeToMotionChangesOptions.deviceLinkId}
 *
 * @example
```ts
#### Subscribe to acceleration changes
```ts
const accelerationHandler = await subscribeToAccelerationChanges({
    deviceLinkId,
});
```
```
 */
export async function subscribeToAccelerationChanges(options) {
    const { deviceLinkId, } = options;
    console.log('subscribeToAccelerationChanges');
    return Motion.addListener('accel', async (accelData) => {
        console.log('accelEvent', accelData);
        const { operations } = await this.makeMotionInsertOperations({
            containerLinkId: deviceLinkId,
            info: accelData,
        });
        await this.serial({
            operations: operations,
        });
    });
}
