import { Motion } from '@capacitor/motion';
/**
 * Subscribes to orientation changes and saves them
 *
 * @remarks
 * Motion permissions should be granted before calling this function by using {@link requestMotionPermissions}
 * Orientation data is saved by using {@link makeMotionValueUpdateOperations} with {@link GetMotionInsertSerialOperationsOptions.containerLinkId} set to {@link SubscribeToMotionChangesOptions.deviceLinkId}
 *
 * @example
```ts
#### Subscribe to orientation changes
```ts
const newOrientationHandler = await subscribeToOrientationChanges({
    deviceLinkId,
});
```
```
 */
export async function subscribeToOrientationChanges(options) {
    const { deviceLinkId, } = options;
    return Motion.addListener('orientation', async (rotationRate) => {
        const { operations } = await this.makeMotionInsertOperations({
            containerLinkId: deviceLinkId,
            info: {
                rotationRate,
            },
        });
        await this.serial({
            operations: operations,
        });
    });
}
